@@ -30,8 +30,9 @@ class setup:
         element = parent.find_element_by_css_selector(css_selector)
         return element.text
 
-    def send(self, css_selector, text, parent=None):
+    def send(self, css_selector, text, clear=True, parent=None):
         if not parent:
             parent = self.driver
         element = parent.find_element_by_css_selector(css_selector)
+        element.clear()
         element.send_keys(text)
\ No newline at end of file
